@@ -2,8 +2,9 @@ package Pcore::App::Controller::Ext;
 
 use Pcore -role, -result;
 use Pcore::Ext;
+use Pcore::Share::Ext_v6_2_0;
 use Pcore::Share::WWW;
-use WWW::CDN;
+use Pcore::Share::WWW::CDN;
 use Pcore::Util::Data qw[to_json];
 
 with qw[Pcore::App::Controller];
@@ -16,6 +17,9 @@ has ext_default_locale        => ( is => 'ro', isa => Str, default => 'en' );
 
 has cache => ( is => 'ro', isa => ScalarRef, init_arg => undef );
 
+our $EXT_VER       = 'v6.2.0';
+our $EXT_FRAMEWORK = 'classic';
+
 sub BUILD ( $self, $args ) {
     Pcore::Ext->SCAN( $self->{app}, 'classic' );
 
@@ -73,11 +77,7 @@ around run => sub ( $orig, $self, $req ) {
     my $resources = [];
 
     # FontAwesome
-    push $resources->@*, WWW::CDN->fontawesome;
-
-    # Ext framework
-    my $ver       = 'v6.2.0';
-    my $framework = 'classic';
+    push $resources->@*, Pcore::Share::WWW->fontawesome;
 
     my $ext_resources;
 
@@ -85,14 +85,14 @@ around run => sub ( $orig, $self, $req ) {
     if ( $req->{env}->{QUERY_STRING} =~ /\btheme=([[:lower:]-]+)/sm ) {
         my $theme = $1;
 
-        $ext_resources = WWW::CDN->extjs( $ver, $framework, $theme, $self->{app}->{devel} );
+        $ext_resources = Pcore::Share::WWW::CDN->ext( $EXT_VER, $EXT_FRAMEWORK, $theme, $self->{app}->{devel} );
     }
 
     # fallback to the default theme
     if ( !$ext_resources ) {
-        my $theme = $framework eq 'classic' ? $self->ext_default_theme_classic : $self->ext_default_theme_modern;
+        my $theme = $EXT_FRAMEWORK eq 'classic' ? $self->ext_default_theme_classic : $self->ext_default_theme_modern;
 
-        $ext_resources = WWW::CDN->extjs( $ver, $framework, $theme, $self->{app}->{devel} );
+        $ext_resources = Pcore::Share::WWW::CDN->ext( $EXT_VER, $EXT_FRAMEWORK, $theme, $self->{app}->{devel} );
     }
 
     push $resources->@*, $ext_resources->@*;
@@ -100,13 +100,13 @@ around run => sub ( $orig, $self, $req ) {
     # Ext locale
     my $locale = $self->ext_default_locale;
 
-    push $resources->@*, WWW::CDN->extjs_locale( $ver, $framework, $locale, $self->{app}->{devel} );
+    push $resources->@*, Pcore::Share::WWW::CDN->ext_locale( $EXT_VER, $EXT_FRAMEWORK, $locale, $self->{app}->{devel} );
 
     # Ext overrides
     my $overrides;
 
     my $class = eval {
-        my $over = $ver =~ s/[.]/_/smgr;
+        my $over = $EXT_VER =~ s/[.]/_/smgr;
 
         P->class->load("Pcore::Ext::Override::$over");
     };
